Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version = "0.0.0-dev"
overridden via linker flags
Functions ¶
This section is empty.
Types ¶
type ATCCommand ¶
type ATCCommand struct {
BindIP IPFlag `long:"bind-ip" default:"0.0.0.0" description:"IP address on which to listen for web traffic."`
BindPort uint16 `long:"bind-port" default:"8080" description:"Port on which to listen for HTTP traffic."`
TLSBindPort uint16 `long:"tls-bind-port" description:"Port on which to listen for HTTPS traffic."`
TLSCert FileFlag `long:"tls-cert" description:"File containing an SSL certificate."`
TLSKey FileFlag `long:"tls-key" description:"File containing an RSA private key, used to encrypt HTTPS traffic."`
ExternalURL URLFlag `long:"external-url" default:"http://127.0.0.1:8080" description:"URL used to reach any ATC from the outside world."`
PeerURL URLFlag `long:"peer-url" default:"http://127.0.0.1:8080" description:"URL used to reach this ATC from other ATCs in the cluster."`
OAuthBaseURL URLFlag `long:"oauth-base-url" description:"URL used as the base of OAuth redirect URIs. If not specified, the external URL is used."`
PostgresDataSource string `` /* 127-byte string literal not displayed */
DebugBindIP IPFlag `long:"debug-bind-ip" default:"127.0.0.1" description:"IP address on which to listen for the pprof debugger endpoints."`
DebugBindPort uint16 `long:"debug-bind-port" default:"8079" description:"Port on which to listen for the pprof debugger endpoints."`
SessionSigningKey FileFlag `long:"session-signing-key" description:"File containing an RSA private key, used to sign session tokens."`
ResourceCheckingInterval time.Duration `long:"resource-checking-interval" default:"1m" description:"Interval on which to check for new versions of resources."`
OldResourceGracePeriod time.Duration `` /* 150-byte string literal not displayed */
ResourceCacheCleanupInterval time.Duration `long:"resource-cache-cleanup-interval" default:"30s" description:"Interval on which to cleanup old caches of resources."`
CLIArtifactsDir DirFlag `long:"cli-artifacts-dir" description:"Directory containing downloadable CLI binaries."`
Developer struct {
DevelopmentMode bool `short:"d" long:"development-mode" description:"Lax security rules to make local development easier."`
Noop bool `short:"n" long:"noop" description:"Don't actually do any automatic scheduling or checking."`
} `group:"Developer Options"`
Worker struct {
GardenURL URLFlag `long:"garden-url" description:"A Garden API endpoint to register as a worker."`
BaggageclaimURL URLFlag `long:"baggageclaim-url" description:"A Baggageclaim API endpoint to register with the worker."`
ResourceTypes map[string]string `` /* 139-byte string literal not displayed */
} `group:"Static Worker (optional)" namespace:"worker"`
BasicAuth struct {
Username string `long:"username" description:"Username to use for basic auth."`
Password string `long:"password" description:"Password to use for basic auth."`
} `group:"Basic Authentication" namespace:"basic-auth"`
GitHubAuth struct {
ClientID string `long:"client-id" description:"Application client ID for enabling GitHub OAuth."`
ClientSecret string `long:"client-secret" description:"Application client secret for enabling GitHub OAuth."`
Organizations []string `long:"organization" description:"GitHub organization whose members will have access." value-name:"ORG"`
Teams []GitHubTeamFlag `long:"team" description:"GitHub team whose members will have access." value-name:"ORG/TEAM"`
Users []string `long:"user" description:"GitHub user to permit access." value-name:"LOGIN"`
AuthURL string `long:"auth-url" description:"Override default endpoint AuthURL for Github Enterprise."`
TokenURL string `long:"token-url" description:"Override default endpoint TokenURL for Github Enterprise."`
APIURL string `long:"api-url" description:"Override default API endpoint URL for Github Enterprise."`
} `group:"GitHub Authentication" namespace:"github-auth"`
UAAAuth UAAAuth `group:"UAA Authentication" namespace:"uaa-auth"`
Metrics struct {
HostName string `long:"metrics-host-name" description:"Host string to attach to emitted metrics."`
Tags []string `long:"metrics-tag" description:"Tag to attach to emitted metrics. Can be specified multiple times." value-name:"TAG"`
Attributes map[string]string `` /* 149-byte string literal not displayed */
YellerAPIKey string `long:"yeller-api-key" description:"Yeller API key. If specified, all errors logged will be emitted."`
YellerEnvironment string `long:"yeller-environment" description:"Environment to tag on all Yeller events emitted."`
RiemannHost string `long:"riemann-host" description:"Riemann server address to emit metrics to."`
RiemannPort uint16 `long:"riemann-port" default:"5555" description:"Port of the Riemann server to emit metrics to."`
} `group:"Metrics & Diagnostics"`
}
func (*ATCCommand) Execute ¶
func (cmd *ATCCommand) Execute(args []string) error
type GitHubTeamFlag ¶
func (*GitHubTeamFlag) UnmarshalFlag ¶
func (flag *GitHubTeamFlag) UnmarshalFlag(value string) error
type UAAAuth ¶
type UAAAuth struct {
ClientID string `long:"client-id" description:"Application client ID for enabling UAA OAuth."`
ClientSecret string `long:"client-secret" description:"Application client secret for enabling UAA OAuth."`
AuthURL string `long:"auth-url" description:"UAA AuthURL endpoint."`
TokenURL string `long:"token-url" description:"UAA TokenURL endpoint."`
CFSpaces []string `long:"cf-space" description:"Space GUID for a CF space whose developers will have access."`
CFURL string `long:"cf-url" description:"CF API endpoint."`
}
func (*UAAAuth) IsConfigured ¶
Click to show internal directories.
Click to hide internal directories.